exoTras delineates exosome profiles at droplet resolution from single-cell transcriptomes
=========================================================================================

**exoTras** /ˈɛkoʊˌtɹeɪs/ stands for <ins>exo</ins>some-containing droplets identification and source <ins>tra</ins>cking in <ins>s</ins>cRNA-seq data.

You can freely use exoTras to explore exosome heterogeneity at single droplet, characterize cell type dynamics in light of exosome activity and unlock diagnostic potential of exosomes in concert with cells.

.. image:: https://github.com/bioinfo-biols/exoTras/blob/main/docs/exoTras_overview.png
   :align: middle

.. toctree::
   :caption: Main
   :maxdepth: 1
   :hidden:

   overview
   installation
   functions

.. toctree::
   :caption: Tutorials
   :maxdepth: 1
   :hidden:

   Exosomes recognizing
   Source tracking
